@@ -1,3 +1,4 @@
+from .exceptions import ImproperlyConfigured
 from .functions import (
     sort_query, defer_except, escape_like, primary_keys, table_name
 )
@@ -9,6 +10,7 @@ from .types import (
     EmailType,
     instrumented_list,
     InstrumentedList,
+    IPAddressType,
     PhoneNumber,
     PhoneNumberType,
     NumberRange,
@@ -17,14 +19,16 @@ from .types import (
     NumberRangeType,
     ScalarListType,
     ScalarListException,
-    TSVectorType
+    TSVectorType,
+    UUIDType,
 )
 
 
-__version__ = '0.14.4'
+__version__ = '0.14.5'
 
 
 __all__ = (
+    ImproperlyConfigured,
     coercion_listener,
     sort_query,
     defer_except,
@@ -37,6 +41,7 @@ __all__ = (
     ColorType,
     EmailType,
     InstrumentedList,
+    IPAddressType,
     Merger,
     NumberRange,
     NumberRangeException,
@@ -47,5 +52,6 @@ __all__ = (
     ProxyDict,
     ScalarListType,
     ScalarListException,
-    TSVectorType
+    TSVectorType,
+    UUIDType,
 )
