@@ -1,9 +1,11 @@
-from colour import Color
+from pytest import mark
 import sqlalchemy as sa
-from sqlalchemy_utils import ColorType
+from sqlalchemy_utils import ColorType, coercion_listener
+from sqlalchemy_utils.types import color
 from tests import TestCase
 
 
+@mark.xfail('color.colour is None')
 class TestColorType(TestCase):
     def create_models(self):
         class Document(self.Base):
@@ -15,8 +17,12 @@ class TestColorType(TestCase):
                 return 'Document(%r)' % self.id
 
         self.Document = Document
+        sa.event.listen(sa.orm.mapper, 'mapper_configured', coercion_listener)
+
 
     def test_color_parameter_processing(self):
+        from colour import Color
+
         document = self.Document(
             bg_color=Color(u'white')
         )
@@ -26,3 +32,10 @@ class TestColorType(TestCase):
 
         document = self.session.query(self.Document).first()
         assert document.bg_color.hex == Color(u'white').hex
+
+    def test_scalar_attributes_get_coerced_to_objects(self):
+        from colour import Color
+
+        document = self.Document(bg_color='white')
+
+        assert isinstance(document.bg_color, Color)
